summaryrefslogtreecommitdiffstats
path: root/kmail/kmkernel.cpp
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-11-16 13:52:38 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-11-16 13:52:38 -0600
commit7dba3110aacdb3220d54c3fe0c2947c25406b700 (patch)
tree28c064cf5647b2e8654cb4d5330d8e64afff27e2 /kmail/kmkernel.cpp
parentc0fc75368b41146e605536e973e1d635b9d64ced (diff)
downloadtdepim-7dba3110aacdb3220d54c3fe0c2947c25406b700.tar.gz
tdepim-7dba3110aacdb3220d54c3fe0c2947c25406b700.zip
Additional renaming of kde to tde
Diffstat (limited to 'kmail/kmkernel.cpp')
-rw-r--r--kmail/kmkernel.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/kmail/kmkernel.cpp b/kmail/kmkernel.cpp
index 54334d8a..3caa18c2 100644
--- a/kmail/kmkernel.cpp
+++ b/kmail/kmkernel.cpp
@@ -146,10 +146,10 @@ KMKernel::KMKernel (TQObject *parent, const char *name) :
new Kpgp::Module();
// register our own (libkdenetwork) utf-7 codec as long as TQt
// doesn't have it's own:
if ( !TQTextCodec::codecForName("utf-7") ) {
- kdDebug(5006) << "No TQt-native utf-7 codec found; registering TQUtf7Codec from libkdenetwork" << endl;
+ kdDebug(5006) << "No TQt-native utf-7 codec found; registering TQUtf7Codec from libtdenetwork" << endl;
(void) new TQUtf7Codec();
}
@@ -146,10 +146,10 @@ KMKernel::KMKernel (TQObject *parent, const char *name) :
new Kpgp::Module();
- // register our own (libkdenetwork) utf-7 codec as long as TQt
+ // register our own (libtdenetwork) utf-7 codec as long as TQt
// doesn't have it's own:
if ( !TQTextCodec::codecForName("utf-7") ) {